HiveFocusQuestStorage class
Hive-backed local persistence for focus sessions and profile state.
- Implemented types
Constructors
- HiveFocusQuestStorage({String boxName = 'focus_quest', HiveInterface? hive, bool initializeHive = true})
- Creates a Hive-backed storage adapter.
Properties
- boxName → String
-
Name of the Hive box used by this adapter.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initializeHive → bool
-
Whether initialize should call
Hive.initFlutter().final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → Future< void> -
Removes all focus quest data from this storage backend.
override
-
initialize(
) → Future< void> -
Prepares the storage backend for reads and writes.
override
-
loadProfile(
) → Future< FocusProfile?> -
Loads the current profile, if one exists.
override
-
loadSessions(
) → Future< List< FocusSession> > -
Loads all stored sessions.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveProfile(
FocusProfile profile) → Future< void> -
Saves the current profile.
override
-
saveSession(
FocusSession session) → Future< void> -
Saves or replaces a session.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited